@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: attach.c,v 2.0 1998/12/12 08:05:44 roessler Rel $";
+static const char rcsid[]="$Id: attach.c,v 2.1 1998/12/28 14:59:04 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -314,7 +314,7 @@ int mutt_view_attachment (FILE *fp, BODY *a, int flag)
   
   is_message = mutt_is_message_type(a->type, a->subtype);
 #ifdef _PGPPATH
-  if (is_message && (a->hdr->pgp & PGPENCRYPT) && !pgp_valid_passphrase())
+  if (is_message && a->hdr && (a->hdr->pgp & PGPENCRYPT) && !pgp_valid_passphrase())
     return (rc);
 #endif /* _PGPPATH */
   use_mailcap = (flag == M_MAILCAP ||
