@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: compose.c,v 2.0 1998/12/12 08:05:55 roessler Rel $";
+static const char rcsid[]="$Id: compose.c,v 2.1 1998/12/16 11:10:23 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -737,6 +737,15 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	  
 	  if ((s = mutt_get_parameter("charset", b->parameter)))
 	    mutt_set_parameter("charset", s, &par);
+	  
+	  /* These are needed for "traditional" PGP.
+	   * Should we switch to a "negative list" instead?
+	   */
+
+	  if ((s = mutt_get_parameter("x-action", b->parameter)))
+	    mutt_set_parameter("x-action", s, &par);
+	  if ((s = mutt_get_parameter("format", b->parameter)))
+	    mutt_set_parameter("format", s, &par);
 
 	  /* ignore the other parameters for now */
 	  mutt_free_parameter(&b->parameter);
