@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: curs_lib.c,v 2.0 1998/12/12 08:06:01 roessler Rel $";
+static const char rcsid[]="$Id: curs_lib.c,v 2.2 1998/12/17 00:52:58 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -115,7 +115,8 @@ int mutt_get_password (char *msg, char *buf, size_t buflen)
 void mutt_clear_error (void)
 {
   Errorbuf[0] = 0;
-  CLEARLINE (LINES-1);
+  if (!option(OPTNOCURSES))
+    CLEARLINE (LINES-1);
 }
 
 void mutt_edit_file (const char *editor, const char *data)
@@ -244,11 +245,23 @@ void mutt_show_error (void)
 
 void mutt_endwin (const char *msg)
 {
+
+#ifdef SLANG_CURSES
+  CLEARLINE (LINES - 1);
+  move (LINES - 1, 0)
+#else
   move (LINES - 1, COLS - 1);
+  CLEARLINE (LINES - 1);
+#endif
+
   attrset (A_NORMAL);
   mutt_refresh ();
   endwin ();
+
+#ifndef SLANG_CURSES
   fputc ('\n', stdout);
+#endif
+
   if (msg)
     puts (msg);
 }
