@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: curs_main.c,v 2.0 1998/12/12 08:06:03 roessler Rel $";
+static const char rcsid[]="$Id: curs_main.c,v 2.3 1998/12/31 09:45:46 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -230,6 +230,24 @@ static int mx_toggle_write (CONTEXT *ctx)
   return 0;
 }
 
+static void resort_index (MUTTMENU *menu)
+{
+  int i;
+  const HEADER *current = CURHDR;
+
+  mutt_sort_headers (Context, 0);
+  /* Restore the current message */
+  for (i = 0; i < Context->vcount; i++)
+  {
+    if (Context->hdrs[Context->v2r[i]] == current)
+    {
+      menu->current = i;
+      break;
+    }
+  }
+  menu->redraw = REDRAW_INDEX | REDRAW_STATUS;
+}
+
 struct mapping_t IndexHelp[] = {
   { N_("Quit"),  OP_QUIT },
   { N_("Del"),   OP_DELETE },
@@ -746,16 +764,7 @@ int mutt_index_menu (void)
 	{
 	  if (Context && Context->msgcount)
 	  {
-	    menu->oldcurrent = CURHDR->index;
-	    mutt_sort_headers (Context, 0);
-
-	    /* try to restore the current message */
-	    for (i = 0; i < Context->vcount; i++)
-	    {
-	      if (Context->hdrs[Context->v2r[i]]->index == menu->oldcurrent)
-		menu->current = i;
-	    }
-	    menu->redraw = REDRAW_INDEX | REDRAW_STATUS;
+	    resort_index (menu);
 	    set_option (OPTSEARCHINVALID);
 	  }
 	}
@@ -943,16 +952,7 @@ int mutt_index_menu (void)
 
 	if (option (OPTNEEDRESORT) && Context && Context->msgcount)
 	{
-	  menu->oldcurrent = CURHDR->index;
-	  mutt_sort_headers (Context, 0);
-
-	  /* try to restore the current message */
-	  for (i = 0; i < Context->vcount; i++)
-	  {
-	    if (Context->hdrs[Context->v2r[i]]->index == menu->oldcurrent)
-	      menu->current = i;
-	  }
-	  menu->redraw = REDRAW_INDEX | REDRAW_STATUS;
+	  resort_index (menu);
 	}
 
 	menu->menu = MENU_PAGER;
@@ -972,8 +972,11 @@ int mutt_index_menu (void)
 	    && (query_quadoption (OPT_QUIT, 
 				  _("Exit Mutt without saving?")) == M_YES))
 	{
-	  mx_fastclose_mailbox (Context);
-	  safe_free ((void **) &Context);
+	  if (Context)
+	  {
+	    mx_fastclose_mailbox (Context);
+	    safe_free ((void **) &Context);
+	  }
 	  done = 1;
 	}
 	break;
@@ -1078,10 +1081,9 @@ int mutt_index_menu (void)
 			       (op == OP_SAVE) || (op == OP_DECODE_SAVE),
 			       (op == OP_DECODE_SAVE) || (op == OP_DECODE_COPY),
 #ifdef _PGPPATH
-			       (op == OP_DECRYPT_SAVE) || (op == OP_DECRYPT_COPY),
-#else
-			       0,
+			       (op == OP_DECRYPT_SAVE) || (op == OP_DECRYPT_COPY) ||
 #endif
+			       0,
 			       &menu->redraw) == 0 &&
 	    (op == OP_SAVE || op == OP_DECODE_SAVE
 #ifdef _PGPPATH
@@ -1468,16 +1470,7 @@ int mutt_index_menu (void)
 	mutt_check_rescore (Context);
 	if (option (OPTNEEDRESORT) && Context && Context->msgcount)
 	{
-	  menu->oldcurrent = CURHDR->index;
-	  mutt_sort_headers (Context, 0);
-
-	  /* try to restore the current message */
-	  for (i = 0; i < Context->vcount; i++)
-	  {
-	    if (Context->hdrs[Context->v2r[i]]->index == menu->oldcurrent)
-	      menu->current = i;
-	  }
-	  menu->redraw = REDRAW_INDEX | REDRAW_STATUS;
+	  resort_index (menu);
 	}
 	if (option (OPTFORCEREDRAWINDEX))
 	  menu->redraw = REDRAW_FULL;
