@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: from.c,v 2.0 1998/12/12 08:06:11 roessler Rel $";
+static const char rcsid[]="$Id: from.c,v 2.1 1998/12/21 10:37:32 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -44,7 +44,7 @@ static int is_day_name (const char *s)
 {
   int i;
 
-  if ((mutt_strlen(s) < 3) || !*(s + 3) || !ISSPACE (*(s+3)))
+  if ((strlen (s) < 3) || !*(s + 3) || !ISSPACE (*(s+3)))
     return 0;
   for (i=0; i<7; i++)
     if (mutt_strncasecmp (s, Weekdays[i], 3) == 0)
