@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: handler.c,v 2.0 1998/12/12 08:06:17 roessler Rel $";
+static const char rcsid[]="$Id: handler.c,v 2.1 1999/01/02 09:35:07 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -1231,14 +1231,8 @@ static void external_body_handler (BODY *b, STATE *s)
   }
 
   expiration = mutt_get_parameter ("expiration", b->parameter);
-  if (expiration) 
-  {
-    /* mutt_parse_date() will alter its argument, so we need a copy */
-    char *e = safe_strdup (expiration);
-
-    expire = mutt_parse_date (e, NULL);
-    free (e);
-  }
+  if (expiration)
+    expire = mutt_parse_date (expiration, NULL);
   else
     expire = -1;
 
