@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: hash.c,v 1.5 1998/11/10 22:14:21 roessler Exp $";
+static const char rcsid[]="$Id: hash.c,v 2.0 1998/12/12 08:06:18 roessler Rel $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  *
@@ -23,11 +23,22 @@ static const char rcsid[]="$Id: hash.c,v 1.5 1998/11/10 22:14:21 roessler Exp $"
 
 #include "mutt.h"
 
+#define SOMEPRIME 149711
+
 int hash_string (const unsigned char *s, int n)
 {
   int h = 0;
+
+#if 0
   while (*s)
     h += *s++;
+#else
+  while (*s)
+    h += (h << 7) + *s++;
+  h = (h * SOMEPRIME) % n;
+  h = (h >= 0) ? h : h + n;
+#endif
+
   return (h % n);
 }
 
