@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: mx.c,v 2.0 1998/12/12 08:06:52 roessler Rel $";
+static const char rcsid[]="$Id: mx.c,v 2.3 1998/12/21 12:38:57 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -582,8 +582,8 @@ CONTEXT *mx_open_mailbox (const char *path, int flags, CONTEXT *pctx)
   set_option (OPTFORCEREFRESH);
 
   /* create hash tables */
-  ctx->id_hash = hash_create (257);
-  ctx->subj_hash = hash_create (257);
+  ctx->id_hash = hash_create (1031);
+  ctx->subj_hash = hash_create (1031);
 
   if (!ctx->quiet)
     mutt_message (_("Reading %s..."), ctx->path);
@@ -642,6 +642,9 @@ CONTEXT *mx_open_mailbox (const char *path, int flags, CONTEXT *pctx)
 void mx_fastclose_mailbox (CONTEXT *ctx)
 {
   int i;
+
+  if(!ctx) 
+    return;
   
 #ifdef USE_IMAP
   if (ctx->magic == M_IMAP)
@@ -674,6 +677,7 @@ static int sync_mailbox (CONTEXT *ctx)
 
   if (!ctx->quiet)
     mutt_message (_("Writing %s..."), ctx->path);
+
   switch (ctx->magic)
   {
     case M_MBOX:
@@ -696,6 +700,9 @@ static int sync_mailbox (CONTEXT *ctx)
 #endif /* USE_IMAP */
   }
 
+  if (!ctx->quiet && rc == -1)
+    mutt_error ( _("Could not synchronize mailbox %s!"), ctx->path);
+  
 #ifdef BUFFY_SIZE
   if (tmp && tmp->new == 0)
     mutt_update_mailbox (tmp);
@@ -712,6 +719,8 @@ int mx_close_mailbox (CONTEXT *ctx)
   char mbox[_POSIX_PATH_MAX];
   char buf[SHORT_STRING];
 
+  if (!ctx) return 0;
+
   ctx->closing = 1;
 
   if (ctx->readonly || ctx->dontwrite)
