@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: pager.c,v 2.0 1998/12/12 08:06:54 roessler Rel $";
+static const char rcsid[]="$Id: pager.c,v 2.2 1998/12/16 11:24:11 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -2265,10 +2265,9 @@ mutt_pager (const char *banner, const char *fname, int flags, pager_t *extra)
 			       (ch == OP_SAVE) || (ch == OP_DECODE_SAVE),
 			       (ch == OP_DECODE_SAVE) || (ch == OP_DECODE_COPY),
 #ifdef _PGPPATH
-			       (ch == OP_DECRYPT_SAVE) || (ch == OP_DECRYPT_COPY),
-#else
-			       0,
+			       (ch == OP_DECRYPT_SAVE) || (ch == OP_DECRYPT_COPY) ||
 #endif
+			       0,
 			       &redraw) == 0 && (ch == OP_SAVE || ch == OP_DECODE_SAVE
 #ifdef _PGPPATH
 						 || ch == OP_DECRYPT_SAVE
@@ -2298,7 +2297,7 @@ mutt_pager (const char *banner, const char *fname, int flags, pager_t *extra)
 	if (option (OPTRESOLVE))
 	{
 	  ch = -1;
-	  rc = OP_MAIN_NEXT_UNDELETED;
+	  rc = OP_NEXT_ENTRY;
 	}
 	break;
 
@@ -2315,7 +2314,7 @@ mutt_pager (const char *banner, const char *fname, int flags, pager_t *extra)
 	if (option (OPTRESOLVE))
 	{
 	  ch = -1;
-	  rc = OP_NEXT_ENTRY;
+	  rc = OP_MAIN_NEXT_UNDELETED;
 	}
 	break;
 
