@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: parse.c,v 2.0 1998/12/12 08:06:56 roessler Rel $";
+static const char rcsid[]="$Id: parse.c,v 2.2 1999/01/02 09:35:08 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -55,7 +55,7 @@ static char *read_rfc822_line (FILE *f, char *line, size_t *linelen)
       return (line);
     }
 
-    buf += mutt_strlen (buf) - 1;
+    buf += strlen (buf) - 1;
     if (*buf == '\n')
     {
       /* we did get a full line. remove trailing space */
@@ -660,7 +660,7 @@ TimeZones[] =
  * This routine assumes that `h' has been initialized to 0.  the `timezone'
  * field is optional, defaulting to +0000 if missing.
  */
-time_t mutt_parse_date (char *s, HEADER *h)
+time_t mutt_parse_date (const char *s, HEADER *h)
 {
   int count = 0;
   char *t;
@@ -673,12 +673,19 @@ time_t mutt_parse_date (char *s, HEADER *h)
   int zoccident = 0;
   const char *ptz;
   char tzstr[SHORT_STRING];
+  char scratch[SHORT_STRING];
 
+  /* Don't modify our argument. Fixed-size buffer is ok here since
+   * the date format imposes a natural limit. 
+   */
+
+  strfcpy (scratch, s, sizeof (scratch));
+  
   /* kill the day of the week, if it exists. */
-  if ((t = strchr (s, ',')))
+  if ((t = strchr (scratch, ',')))
     t++;
   else
-    t = s;
+    t = scratch;
   SKIPWS (t);
 
   memset (&tm, 0, sizeof (tm));
@@ -1165,7 +1172,7 @@ ENVELOPE *mutt_read_rfc822_header (FILE *f, HEADER *hdr, short user_hdrs)
       }
       else
 	last = e->userhdrs = mutt_new_list ();
-      line[mutt_strlen (line)] = ':';
+      line[strlen (line)] = ':';
       last->data = safe_strdup (line);
     }
 
