@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: pgp.c,v 2.0 1998/12/12 08:07:00 roessler Rel $";
+static const char rcsid[]="$Id: pgp.c,v 2.1 1998/12/30 07:58:40 roessler Exp $";
 /*
  * Copyright (C) 1996,1997 Michael R. Elkins <me@cs.hmc.edu>
  * Copyright (c) 1998 Thomas Roessler <roessler@guug.de>
@@ -461,7 +461,7 @@ void application_pgp_handler (BODY *m, STATE *s)
 	else if (pgp_keyblock)
 	  state_puts (_("[-- END PGP PUBLIC KEY BLOCK --]\n"), s);
 	else
-	  state_puts ("\n[-- END PGP SIGNED MESSAGE --]\n", s);
+	  state_puts (_("\n[-- END PGP SIGNED MESSAGE --]\n"), s);
       }
     }
     else
