@@ -1,4 +1,4 @@
-/* $Id: protos.h,v 2.0 1998/12/12 08:07:09 roessler Rel $ */
+/* $Id: protos.h,v 2.1 1999/01/02 09:35:09 roessler Exp $ */
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -97,7 +97,7 @@ ATTACHPTR **mutt_gen_attach_list (BODY *, int, ATTACHPTR **, short *, short *, i
 time_t mutt_local_tz (void);
 time_t mutt_mktime (struct tm *, int);
 time_t is_from (const char *, char *, size_t);
-time_t mutt_parse_date (char *, HEADER *);
+time_t mutt_parse_date (const char *, HEADER *);
 
 const char *mutt_attach_fmt (
 	char *dest,
