@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: sendlib.c,v 2.0 1998/12/12 08:07:24 roessler Rel $";
+static const char rcsid[]="$Id: sendlib.c,v 2.3 1999/01/02 17:23:24 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -986,6 +986,7 @@ BODY *mutt_make_message_attach (CONTEXT *ctx, HEADER *hdr, int attach_msg)
   chflags = CH_XMIT;
   cmflags = 0;
 
+  /* If we are attaching a message, ignore OPTMIMEFORWDECODE */
   if (!attach_msg && option (OPTMIMEFORWDECODE))
   {
     chflags |= CH_MIME | CH_TXTPLAIN;
@@ -994,8 +995,8 @@ BODY *mutt_make_message_attach (CONTEXT *ctx, HEADER *hdr, int attach_msg)
     pgp &= ~PGPENCRYPT;
 #endif
   }
-  else
 #ifdef _PGPPATH
+  else
     if(option(OPTFORWDECRYPT)
        && (hdr->pgp & PGPENCRYPT))
   {
@@ -1014,7 +1015,6 @@ BODY *mutt_make_message_attach (CONTEXT *ctx, HEADER *hdr, int attach_msg)
   }
 #endif
 
-  /* If we are attaching a message, ignore OPTMIMEFORWDECODE */
   mutt_copy_message (fp, ctx, hdr, cmflags, chflags);
   
   fflush(fp);
@@ -1154,7 +1154,12 @@ char *mutt_make_date (char *s, size_t len)
   yday = l->tm_yday - yday;
 
   if (yday != 0)
+  {
+    if (yday > 1 || yday < -1)
+      yday /= - abs (yday);
+
     tz += yday * 24 * 60; /* GMT is next or previous day! */
+  }
 
   snprintf (s, len,  "Date: %s, %d %s %d %02d:%02d:%02d %+03d%02d\n",
 	   Weekdays[l->tm_wday], l->tm_mday, Months[l->tm_mon], l->tm_year+1900,
